Chained Validation
==================

Chained Validation is an extensive pack of *customizable*, *extensible* and *chainable* validations to your objects.

To ensure that only valid data is saved to your database, or that it is handled in your application effectively,
validations are used. For example, the client using your application may forget for a `dot` (.) or an `at` (@) email
address field, so to ensure that each input is actually a valid data, chained validation will help you.

- Validate simple rules: `rule_for('foo').is_string.validate`.
- Validate the complex with simple chained rules: `rule_for(5).is_integer.positive.validate`.
- Built in and fully tested validation rules.

How to install
==============

For Ruby projects:

```shell
$ gem install chained_validation
```

For Rails projects, insert in your gemfile:

```ruby
gem 'chained_validation', '~> 0.0.7'
```

After install require chained validation in your project:

```ruby
require 'chained_validation'
```

And include in your models or classes:

```ruby
include ChainedValidation
```

How create a validation
=====================

After install Chained Validation, a minimal implementation could be:

```ruby
rule_for('londerson@gmail.com').is_email.validate # => true
```

```ruby
rule_for(5).is_string.validate # => false
```

In Ruby, everything is an object. Therefore, invariably you will insert an object to be validated by `rule_for`.
The result is delivered by calling the `validate` method:

How create a chained validation
================================

Through the fluent interface, you can create chained validations. The `validate` method, that can be called at the end, will
deliver the result of the operation (i.e. `#=> true` or `#=> false`).

```ruby
rule_for(5).is_integer.is_positive.is_equals(5).validate # => true
```

Built in rules
=====

### is_boolean

Validates if the input is a boolean value:

```ruby
rule_for(true).is_boolean.validate # => true
```

### positive

Validates if a number is higher than zero:

```ruby
rule_for(10).positive.validate # => true
```

### negative

Validates if a number is less than zero:

```ruby
rule_for(-10).negative.validate # => true
```

### multiple_of

Validates if the input is a multiple of the given parameter:

```ruby
rule_for(5).multiple_of(10).validate # => true
```

### is_integer

Validates whether the type of a value is integer:

```ruby
rule_for(5).is_integer.validate # => true
```

### Date

Validates if input is a date:

```ruby
rule_for('12/05/2017').is_date.validate # => true
```

### is_string

Validates if input is a string:

```ruby
rule_for('Foo').is_string.validate # => true
```

### is_empty

Validates if input is empty:

```ruby
rule_for('').is_empty.validate # => true
```

### is_downcase

Validates if input is downcase:

```ruby
rule_for('foo').is_downcase.validate # => true
```

### is_uppercase

Validates if input is uppercase:

```ruby
rule_for('foo').is_uppercase.validate # => true
```

### is_email

Validates if input is a valid email format:

```ruby
rule_for('foo@gmail.com').is_email.validate # => true
```

### is_json

Validates if input is a valid json format:

```ruby
rule_for('{"name": "foo"}').is_json.validate # => true
```

### rg

Validates if input is a valid RG format (Registro Geral):

```ruby
rule_for('418757896').rg.validate # => true
```

### domain

Validates if input is a valid domain format:

```ruby
rule_for('http://www.google.com').domain.validate # => true
```

### equals_with

Validates if the input is equal to some value:

```ruby
rule_for('foo').equals_with('foo').validate # => true
```

### contains

Validates if the input contains to some value:

```ruby
rule_for('foo bar').contains('foo').validate # => true
```

### roman

Validates if input is a roman number:

```ruby
rule_for('V').roman.validate # => true
```

### begins_with

Validates only if the value is at the beginning of the input:

```ruby
rule_for('Lorem ipsum lorem').begins_with('Lorem).validate # => true
```

### ends_with

Validates only if the value is at the endning of the input:

```ruby
rule_for('Lorem ipsum lorem').ends_with('lorem).validate # => true
```

Contributing
============

1. Fork it (https://github.com/Londerson/chained_validation)
2. Create your feature branch (`git checkout -b new_feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin new_feature`)
5. Create a new Pull Request

License
=======

Copyright © 2014 Londerson Araújo, released under the MIT license
